@@ -3,7 +3,7 @@
 ;; @Keywords: text, syntax, processes, tools
 ;; @Version: 4.0.8 2013-02-17 (3.0.7 2011-04-20) (2008-12-14)
 ;;   [3.0.7 2011-04-20 Ambrose Kofi Laing & Ralph Amissah]
-;;   [4.0.9 2013-02-22 Ralph Amissah]
+;;   [5.7.2 2014-10-28 Ralph Amissah]
 ;; @URL: <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=data/sisu/conf/editor-syntax-etc/emacs/sisu-mode.el;hb=HEAD>
 ;; @Copyright: Assigned to FSF 2011-04-08 (GNU EMACS)
 ;; @License: GPLv3
@@ -331,6 +331,21 @@
   )
   "Default expressions to highlight in AsciiSisu mode."
 )
+;; enables outlining for sisu
+(add-hook 'sisu-mode-hook
+       '(lambda ()
+         (outline-minor-mode)
+         (setq outline-regexp "^\\(\\([1-4]\\|:?[A-D]\\)\\~\\|\\@[a-z]+:\\( \\|$\\)\\)")))
+;; outline mode "folding" if available
+;(define-key evil-normal-state-map (kbd ",0") (lambda() (interactive) (show-all)))
+;(define-key evil-normal-state-map (kbd ",-") (lambda() (interactive) (hide-body)))
+;(define-key evil-normal-state-map (kbd ",+") (lambda() (interactive) (show-subtree)))
+;(define-key evil-normal-state-map (kbd ",=") (lambda() (interactive) (show-subtree)))
+;; C-c @ C-a show all
+;; C-c @ C-t show only the headings
+;; C-c @ C-s show subtree at cursor location
+;; C-c @ C-d hide subtree at cursor location
+
 ;; Sisu & Autoload:
 ;; ##autoload
 (define-derived-mode sisu-mode text-mode "SiSU"
