@@ -64,7 +64,7 @@ module SiSU_AO
   require_relative 'ao_syntax'                          # ao_syntax.rb
     include SiSU_AO_Syntax
   require_relative 'ao_doc_str'                         # ao_doc_str.rb
-  require_relative 'ao_references'                      # ao_references.rb
+  require_relative 'ao_appendices'                      # ao_appendices.rb
   require_relative 'ao_idx'                             # ao_idx.rb
   require_relative 'ao_numbering'                       # ao_numbering.rb
   require_relative 'ao_hash_digest'                     # ao_hash_digest.rb
@@ -534,38 +534,38 @@ module SiSU_AO
       reset
       data_txt=@data
       data_txt=
-        SiSU_AO_Insertions::Insertions.new(@md,data_txt).            # ao_expand_insertions.rb
+        SiSU_AO_Insertions::Insertions.new(@md,data_txt).                  # ao_expand_insertions.rb
           expand_insertions?
       data_txt=
-        SiSU_AO_MiscArrangeText::SI.new(@md,data_txt).               # ao_misc_arrange.rb
+        SiSU_AO_MiscArrangeText::SI.new(@md,data_txt).                     # ao_misc_arrange.rb
           prepare_text
       data_obj,
         metadata,
         bibliography=
-          SiSU_AO_DocumentStructureExtract::Build.new(@md,data_txt). # ao_doc_str.rb
+          SiSU_AO_DocumentStructureExtract::Build.new(@md,data_txt).       # ao_doc_str.rb
             identify_parts
       data_obj=
-        SiSU_AO_Syntax::Markup.new(@md,data_obj,bibliography).songsheet           # ao_syntax.rb
+        SiSU_AO_Syntax::Markup.new(@md,data_obj,bibliography).songsheet    # ao_syntax.rb
       data_obj,
         endnote_array=
-          SiSU_AO_CharacterCheck::Check.new(data_obj).               # ao_character_check.rb
+          SiSU_AO_CharacterCheck::Check.new(data_obj).                     # ao_character_check.rb
             character_check_and_oldstyle_endnote_array
       data_obj=
-         SiSU_AO_Images::Images.new(@md,data_obj).images             # ao_images.rb
+         SiSU_AO_Images::Images.new(@md,data_obj).images                   # ao_images.rb
       data_obj,
         tags_map,
         ocn_html_seg_map=
-          SiSU_AO_Numbering::Numbering.new(@md,data_obj,@fnx,@process). # ao_numbering.rb
+          SiSU_AO_Numbering::Numbering.new(@md,data_obj,@fnx,@process).    # ao_numbering.rb
             numbering_song
       data_obj,
         book_index_rel,
         book_index_rel_html_seg,
         html_idx,
         xhtml_idx=
-          SiSU_AO_BookIndex::BookIndex.new(@md,data_obj,@env).       # ao_idx.rb
+          SiSU_AO_BookIndex::BookIndex.new(@md,data_obj,@env).             # ao_idx.rb
             indexing_song if @md.book_idx
       data_obj=
-        SiSU_AO_Endnotes::Endnotes.new(@md,data_obj,endnote_array).  # ao_endnotes.rb
+        SiSU_AO_Endnotes::Endnotes.new(@md,data_obj,endnote_array).        # ao_endnotes.rb
           endnotes
       outputdata=data_obj
       if (@md.opt.act[:ao][:set]==:on \
